#include "prog.h"

int main(int argc, char **argv)
{
	if (start(argc, argv) != 0)
		return 1;

	main_loop();

	return e_close();
}
